@@ -77,7 +77,6 @@ as_function.formula <- function(.f, ...) {
 }
 
 
-#' @useDynLib purrr extract_impl
 extract <- function(x, index, .null = NULL) {
   .Call(extract_impl, x, index, .null)
 }
@@ -113,7 +112,7 @@ as_function.default <- function(.f, ...) {
 
 maybe_as_data_frame <- function(out, x) {
   if (is.data.frame(x)) {
-    dplyr::as_data_frame(out)
+    tibble::as_tibble(out)
   } else {
     out
   }
